package be.iminds.ilabt.jfed.ui.cli2.instruction;

import be.iminds.ilabt.jfed.experiment.setup.ExperimentSetupConfig;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.List;

public class SliceInfoInstruction extends InstructionWithSlice {
    private final boolean showStatus;
    private final boolean showMetaInfo;
    private final boolean showUsers;
    private final boolean showCredentials;

    @JsonCreator
    public SliceInfoInstruction(@JsonProperty("action") @Nonnull Action action,
                                @JsonProperty("user") @Nullable User user,
                                @JsonProperty("actionOutputs") @Nullable List<ActionOutput> actionOutputs,
                                @JsonProperty("debugOutputs") @Nullable List<DebugOutput> debugOutputs,
                                @JsonProperty("callOutputs") @Nullable List<CallOutput> callOutputs,
                                @JsonProperty("proxy") @Nullable ProxySettings proxy,
                                @JsonProperty("slice") @Nullable ExperimentSetupConfig.Slice slice,
                                @JsonProperty("showStatus") @Nullable Boolean showStatus,
                                @JsonProperty("showMetaInfo") @Nullable Boolean showMetaInfo,
                                @JsonProperty("showUsers") @Nullable Boolean showUsers,
                                @JsonProperty("showCredentials") @Nullable Boolean showCredentials) {
        super(action, user, actionOutputs, debugOutputs, callOutputs, proxy, slice);
        this.showStatus = showStatus == null ? new SliceInfoInstruction(false).showStatus : showStatus;
        this.showMetaInfo = showMetaInfo == null ? new SliceInfoInstruction(false).showMetaInfo : showMetaInfo;
        this.showUsers = showUsers == null ? new SliceInfoInstruction(false).showUsers : showUsers;
        this.showCredentials = showCredentials == null ? new SliceInfoInstruction(false).showCredentials : showCredentials;
    }

    public SliceInfoInstruction(boolean demo) {
        super(Action.SLICEINFO, demo, true);
        this.showStatus = true;
        this.showMetaInfo = true;
        this.showUsers = true;
        this.showCredentials = false;
    }

    @JsonProperty
    public boolean isShowStatus() {
        return showStatus;
    }

    @JsonProperty
    public boolean isShowMetaInfo() {
        return showMetaInfo;
    }

    @JsonProperty
    public boolean isShowUsers() {
        return showUsers;
    }

    @JsonProperty
    public boolean isShowCredentials() {
        return showCredentials;
    }

    @JsonIgnore
    @Nonnull
    @Override
    public Action getActionOfClass() {
        return Action.SLICEINFO;
    }
}
